--- a/tools/qvfb/qvfbview.cpp Tue Jan 26 12:42:25 2010 +0200
+++ b/tools/qvfb/qvfbview.cpp Tue Feb 02 00:43:10 2010 +0200
@@ -108,8 +108,8 @@
break;
}
- connect(mView, SIGNAL(displayDataChanged(const QRect &)),
- SLOT(refreshDisplay(const QRect &)));
+ connect(mView, SIGNAL(displayDataChanged(QRect)),
+ SLOT(refreshDisplay(QRect)));
#ifdef Q_WS_X11
connect(mView, SIGNAL(displayEmbedRequested(WId)),
this, SLOT(embedDisplay(WId)));
@@ -596,7 +596,7 @@
r.width(), r.height(), mView->linestep(),
QImage::Format_Indexed8);
img.setColorTable(mView->clut());
- if (img.numColors() <= 0)
+ if (img.colorCount() <= 0)
img = QImage();
break;
}
@@ -613,10 +613,10 @@
if ( img.format() != QImage::Format_ARGB32_Premultiplied )
img = img.convertToFormat(QImage::Format_RGB32);
// NOTE: calling bits() may change numBytes(), so do not
// pass them as parameters (which are evaluated right-to-left).
QRgb *b = (QRgb*)img.bits();
- int n = img.numBytes()/4;
+ int n = img.byteCount()/4;
dim(b,n,brightness);
}
}
@@ -613,10 +613,10 @@
if ( img.format() != QImage::Format_ARGB32_Premultiplied )
img = img.convertToFormat(QImage::Format_RGB32);
- // NOTE: calling bits() may change numBytes(), so do not
+ // NOTE: calling bits() may change byteCount(), so do not
// pass them as parameters (which are evaluated right-to-left).
QRgb *b = (QRgb*)img.bits();